@@ -52,10 +52,10 @@ protected:
   virtual Gnome::Gda::Value get_entered_field_data(const LayoutItem_Field& field) const;
   virtual void set_entered_field_data(const LayoutItem_Field& field, const Gnome::Gda::Value& value);
 
-  bool get_field_primary_key_for_table(const Glib::ustring table_name, Field& field) const;
+  bool get_field_primary_key_for_table(const Glib::ustring& table_name, Field& field) const;
   //static bool get_field_primary_key(const type_vecFields& fields, Field& field);
 
-  unsigned long get_last_auto_increment_value(const Glib::RefPtr<Gnome::Gda::DataModel>& data_model, const Glib::ustring field_name);
+  unsigned long get_last_auto_increment_value(const Glib::RefPtr<Gnome::Gda::DataModel>& data_model, const Glib::ustring& field_name);
 
 
   static type_vecFields get_fields_for_datamodel(const Glib::RefPtr<Gnome::Gda::DataModel>& data_model); 
