@@ -693,9 +693,15 @@ void Document_Glom::fill_layout_field_details(const Glib::ustring& parent_table_
     }
     else
     {
-      LayoutGroup* layout_group_child = dynamic_cast<LayoutGroup*>(layout_item);
-      if(layout_group_child)
-        fill_layout_field_details(parent_table_name, *layout_group_child); //recurse
+      LayoutItem_Portal* layout_portal_child = dynamic_cast<LayoutItem_Portal*>(layout_item);
+      if(layout_portal_child)
+        fill_layout_field_details(layout_portal_child->m_relationship.get_to_table(), *layout_portal_child); //recurse
+      else
+      {  
+        LayoutGroup* layout_group_child = dynamic_cast<LayoutGroup*>(layout_item);
+        if(layout_group_child)
+          fill_layout_field_details(parent_table_name, *layout_group_child); //recurse
+      }
     }
   }
 }
@@ -823,17 +829,9 @@ Document_Glom::type_mapLayoutGroupSequence Document_Glom::get_data_layout_groups
   return type_mapLayoutGroupSequence(); //not found
 }
 
-void Document_Glom::set_relationship_data_layout_groups(const Glib::ustring& layout_name, const Relationship& relationship, const type_mapLayoutGroupSequence& groups)
+void Document_Glom::set_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const type_mapLayoutGroupSequence& groups)
 {
-  //TODO: Use an actual relationship_name instead of concatenating:
-  set_data_layout_groups(layout_name + "_related_" + relationship.get_name(), relationship.get_from_table(), groups, relationship.get_to_table());
-}
-
-void Document_Glom::set_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const type_mapLayoutGroupSequence& groups, const Glib::ustring& table_name)
-{
-  Glib::ustring child_table_name = table_name;
-  if(child_table_name.empty())
-    child_table_name = parent_table_name;
+  Glib::ustring child_table_name = parent_table_name; //TODO: Remove this cruft.
 
   //g_warning("Document_Glom::set_data_layout_groups(): ADDING layout for table %s (child_table=%s), for layout %s", parent_table_name.c_str(), child_table_name.c_str(), layout_name.c_str());
 
@@ -900,6 +898,15 @@ bool Document_Glom::get_table_is_known(const Glib::ustring& table_name) const
   return (iterFind != m_tables.end());
 }
 
+bool Document_Glom::get_table_is_hidden(const Glib::ustring& table_name) const
+{
+  type_tables::const_iterator iterFind = m_tables.find(table_name);
+  if(iterFind != m_tables.end())
+    return iterFind->second.m_info.m_hidden;
+  else
+    return false; //It's not even known.
+}
+
 AppState::userlevels Document_Glom::get_userlevel() const
 {
   userLevelReason reason;
@@ -1720,7 +1727,9 @@ bool Document_Glom::save_before()
           xmlpp::Element* nodeGroups = nodeReport->add_child(GLOM_NODE_DATA_LAYOUT_GROUPS);
           save_before_layout_group(nodeGroups, iter->second.m_layout_group);
         }
-
+        
+        
+        nodeTable->add_child_text("\n\n"); //Make it a bit easier to read, 
       }
 
     } //for m_tables
@@ -1744,7 +1753,7 @@ bool Document_Glom::save_before()
       nodeGroup->set_attribute(GLOM_ATTRIBUTE_NAME, group_info.m_name);
       set_node_attribute_value_as_bool(nodeGroup, GLOM_ATTRIBUTE_DEVELOPER, group_info.m_developer);
 
-      //The privilieges for each table, for this group:
+      //The privileges for each table, for this group:
       for(GroupInfo::type_map_table_privileges::const_iterator iter = group_info.m_map_privileges.begin(); iter != group_info.m_map_privileges.end(); ++iter)
       {
         xmlpp::Element* nodeTablePrivs = nodeGroups->add_child(GLOM_NODE_TABLE_PRIVS);
@@ -1998,4 +2007,53 @@ void Document_Glom::remove_report(const Glib::ustring& table_name, const Glib::u
   }
 }
 
+bool Document_Glom::get_relationship_is_to_one(const Glib::ustring& table_name, const Glib::ustring& relationship_name) const
+{
+  Relationship relationship;
+  bool found = get_relationship(table_name, relationship_name, relationship);
+  if(found)
+  {
+    Field field_to;
+    bool found = get_field(relationship.get_to_table(), relationship.get_to_field(), field_to);
+    if(found)
+      return (field_to.get_primary_key() || field_to.get_unique_key());
+  }
+  
+  return false;
+}
+  
+bool Document_Glom::get_field_used_in_relationship_to_one(const Glib::ustring& table_name, const Glib::ustring& field_name, Relationship& relationship) const
+{
+  //Initialize input parameter:
+  relationship = Relationship();
+  
+  type_tables::const_iterator iterFind = m_tables.find(table_name);
+  if(iterFind != m_tables.end())
+  {
+    //Look at each relationship:
+    for(type_vecRelationships::const_iterator iterRel = iterFind->second.m_relationships.begin(); iterRel != iterFind->second.m_relationships.end(); ++iterRel)
+    {
+      //If the relationship uses the field
+      if(iterRel->get_from_field() == field_name)
+      {
+        //if the to_table is not hidden:
+        if(!get_table_is_hidden(iterRel->get_to_table()))
+        {
+          //TODO_Performance: The use of this convenience method means we get the full relationship information again:
+          if(get_relationship_is_to_one(table_name, iterRel->get_name()))
+          {
+            relationship = *iterRel;
+            return true;
+          }
+        }
+      }
+    }
+  }
+  return false;
+}
 
+bool Document_Glom::get_field_used_in_relationship_to_one(const Glib::ustring& table_name, const Glib::ustring& field_name) const
+{
+  Relationship relationship; //ignored.
+  return get_field_used_in_relationship_to_one(table_name, field_name, relationship);
+}
