@@ -76,13 +76,26 @@ public:
 
   typedef std::vector<Relationship> type_vecRelationships;
   virtual type_vecRelationships get_relationships(const Glib::ustring& table_name) const;
-  virtual void set_relationships(const Glib::ustring& table_name, const type_vecRelationships& vecRelationships);
+  void set_relationships(const Glib::ustring& table_name, const type_vecRelationships& vecRelationships);
 
-  virtual bool get_relationship(const Glib::ustring& table_name, const Glib::ustring& relationship_name, Relationship& relationship) const;
-  virtual void set_relationship(const Glib::ustring& table_name, const Relationship& relationship);
+  bool get_relationship(const Glib::ustring& table_name, const Glib::ustring& relationship_name, Relationship& relationship) const;
+  void set_relationship(const Glib::ustring& table_name, const Relationship& relationship);
 
-  virtual void remove_relationship(const Relationship& relationship);
+  void remove_relationship(const Relationship& relationship);
+  
+  /** Returns whether the relationship's to-field is a primary key  or unique field, meaning
+   * that there can be only one related record for each value of the from-field.
+   */
+  bool get_relationship_is_to_one(const Glib::ustring& table_name, const Glib::ustring& relationship_name) const;
+  
+  
+  /** Returns whether the field is the from-field in a to-one relationship.
+   * @see get_relationship_is_to_one(). Ignores hidden tables.
+   */
+  bool get_field_used_in_relationship_to_one(const Glib::ustring& table_name, const Glib::ustring& field_name) const;
+  bool get_field_used_in_relationship_to_one(const Glib::ustring& table_name, const Glib::ustring& field_name, Relationship& relationship) const;
 
+    
   typedef std::vector<Field> type_vecFields;
   virtual type_vecFields get_table_fields(const Glib::ustring& table_name) const;
   virtual void set_table_fields(const Glib::ustring& table_name, const type_vecFields& vecFields);
@@ -91,31 +104,28 @@ public:
 
 
   typedef std::map<guint, LayoutGroup> type_mapLayoutGroupSequence;
-  virtual type_mapLayoutGroupSequence get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const Glib::ustring& table_name = Glib::ustring()) const;
+  virtual type_mapLayoutGroupSequence get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name) const;
 
-  virtual void set_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const type_mapLayoutGroupSequence& groups, const Glib::ustring& table_name = Glib::ustring());
-
-  virtual void set_relationship_data_layout_groups(const Glib::ustring& layout_name, const Relationship& relationship, const type_mapLayoutGroupSequence& groups);
+  virtual void set_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const type_mapLayoutGroupSequence& groups);
 
   /**
-   * @para The layout_name, such as "details", "list", or "related_invoice_lines".
+   * @para The layout_name, such as "details", "list".
    * @para parent_table_name The name of the table on whose layout the layout appears.
-   * @para table_name The name of the related table, if this is a related layout.
    */
-  virtual type_mapLayoutGroupSequence get_data_layout_groups_plus_new_fields(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name, const Glib::ustring& table_name = Glib::ustring()) const;
-
-  virtual type_mapLayoutGroupSequence get_relationship_data_layout_groups_plus_new_fields(const Glib::ustring& layout_name, const Relationship& relationship) const;
-
+  virtual type_mapLayoutGroupSequence get_data_layout_groups_plus_new_fields(const Glib::ustring& layout_name, const Glib::ustring& parent_table_name) const;
 
   virtual void fill_layout_field_details(const Glib::ustring& parent_table_name, LayoutGroup& layout_group) const;
   virtual void fill_layout_field_details(const Glib::ustring& parent_table_name, type_mapLayoutGroupSequence& sequence) const;
 
 
-  ///When a field name is changed, change it in the relationships and fields data:
+  ///When a field name is changed, change it in the relationships, layouts, reports, and fields data:
   virtual void change_field_name(const Glib::ustring& table_name, const Glib::ustring& strFieldNameOld, const Glib::ustring& strFieldNameNew);
 
   ///When a table name is changed, change it in the relationships and tables data:
   virtual void change_table_name(const Glib::ustring& strTableNameOld, const Glib::ustring& strTableNameNew);
+  
+  ///When a relationship name is changed, change it in layouts and reports:
+  virtual void change_relationship_name(const Glib::ustring& table_name, const Glib::ustring& name, const Glib::ustring& name_new);
 
   typedef std::list<TableInfo> type_listTableInfo;
   virtual type_listTableInfo get_tables() const;
@@ -128,6 +138,7 @@ public:
   virtual void remove_table(const Glib::ustring& table_name);
 
   virtual bool get_table_is_known(const Glib::ustring& table_name) const;
+  virtual bool get_table_is_hidden(const Glib::ustring& table_name) const;
 
   virtual Glib::ustring get_table_title(const Glib::ustring& table_name) const;
   virtual void set_table_title(const Glib::ustring& table_name, const Glib::ustring& value);
