@@ -27,6 +27,7 @@
 #include "../../dialog_invalid_data.h"
 #include "../../application.h"
 #include "../../utils.h"
+#include "cellrenderer_button.h"
 //#include "../cellrendererlist.h"
 #include <iostream> //For debug output.
 
@@ -61,7 +62,9 @@ DbAddDel::DbAddDel()
   m_allow_add(true),
   m_allow_delete(true),
   m_columns_ready(false),
-  m_allow_view(true)
+  m_allow_view(true),
+  m_allow_view_details(false),
+  m_treeviewcolumn_button(0)
 {
   set_prevent_user_signals();
   set_ignore_treeview_signals();
@@ -287,17 +290,20 @@ bool DbAddDel::on_button_press_event_Popup(GdkEventButton *event)
   {
     //Give user choices of actions on this item:
     m_pMenuPopup->popup(event->button, event->time);
+    return true; //handled.
   }
   else
   {
     if(event->type == GDK_2BUTTON_PRESS)
     {
       //Double-click means edit.
-      on_MenuPopup_activate_Edit();
+      //Don't do this, because users sometimes double-click by accident when they just want to edit a cell.
+      //on_MenuPopup_activate_Edit();
+      return false; //Not handled.
     }
   }
 
-  return true;
+  return  false; //Not handled. TODO: Call base class?
 }
 
 Gtk::TreeModel::iterator DbAddDel::get_item_placeholder()
@@ -637,6 +643,19 @@ void DbAddDel::construct_specified_columns()
   //Add new View Colums:
   int model_column_index = 0; //Not including the hidden internal columns.
   int view_column_index = 0;
+  
+  {
+    GlomCellRenderer_Button* pCellButton = Gtk::manage(new GlomCellRenderer_Button());
+    pCellButton->signal_clicked().connect(sigc::mem_fun(*this, &DbAddDel::on_cell_button_clicked));
+    
+    const int viewcols_count = m_TreeView.append_column(Glib::ustring(), *pCellButton);
+    m_treeviewcolumn_button = m_TreeView.get_column(viewcols_count - 1);
+    
+    m_treeviewcolumn_button->property_visible() = get_allow_view_details();
+    
+    ++view_column_index;
+  }
+  
   for(type_vecModelColumns::iterator iter = vecModelColumns.begin(); iter != vecModelColumns.end(); ++iter)
   {
     DbAddDelColumnInfo& column_info = m_ColumnTypes[model_column_index];
@@ -1693,5 +1712,31 @@ void DbAddDel::set_allow_view(bool val)
   m_allow_view = val;
 }
 
+void DbAddDel::set_allow_view_details(bool val)
+{
+  m_allow_view_details = val;
+  
+  //Hide it if it was visible:
+  if(m_treeviewcolumn_button)
+    m_treeviewcolumn_button->property_visible() = get_allow_view_details();
+}
+
+bool DbAddDel::get_allow_view_details() const
+{
+  return m_allow_view_details;
+}
+
+void DbAddDel::on_cell_button_clicked(const Gtk::TreeModel::Path& path)
+{
+  Gtk::TreeModel::iterator iter = m_refListStore->get_iter(path);
+  if(iter)
+  {
+    const guint first_visible = get_count_hidden_system_columns();
+    select_item(iter, first_visible, false /* start_editing */);
+  }
+  
+  on_MenuPopup_activate_Edit();
+}
+
 
 
