@@ -25,6 +25,7 @@
 #include "../../data_structure/layout/layoutitem_field.h"
 #include <libgdamm.h>
 #include "glom_db_treemodel.h"
+#include "../../document/document_glom.h"
 
 #include <vector>
 #include <map>
@@ -51,7 +52,9 @@ class DbTreeViewColumnGlom;
 
 //For adding/deleting/selecting multi-columned lists of items.
 //This was also an abstraction layer against the strangeness of GtkSheet, though it now uses Gtk::TreeView instead.
-class DbAddDel : public Gtk::VBox
+class DbAddDel
+ : public Gtk::VBox,
+   public View_Composite_Glom
 {
 public:
   friend class InnerIgnore; //declared below.
@@ -132,6 +135,11 @@ public:
 
   ///For instance, if the user can not view the table then don't try to get the records.
   virtual void set_allow_view(bool val = true);
+  
+  ///Whether each row should have a button, to request edit.
+  void set_allow_view_details(bool val = true);
+  bool get_allow_view_details() const;
+
 
   /** @result The index of the new column.
    */
@@ -164,6 +172,8 @@ public:
 
   virtual void construct_specified_columns(); //Delay actual use of set_column_*() stuff until this method is called.
 
+  virtual bool refresh_from_database();
+
   virtual void set_show_column_titles(bool bVal = true);
 
   virtual Gtk::TreeModel::iterator get_row(const Gnome::Gda::Value& key);
@@ -257,7 +267,7 @@ protected:
   virtual void on_treeview_button_press_event(GdkEventButton* event);
 
   virtual bool on_treeview_columnheader_button_press_event(GdkEventButton* event);
-
+  virtual void on_cell_button_clicked(const Gtk::TreeModel::Path& path);  
 
   bool get_prevent_user_signals() const;
 
@@ -291,9 +301,6 @@ protected:
   typedef DbTreeModel type_model_store;
   Glib::RefPtr<type_model_store> m_refListStore;
 
-  //Hidden internal columns:
-  Gtk::TreeModelColumn<Gnome::Gda::Value>* m_modelcolumn_key; 
-
   //Columns, not including the hidden internal columns:
   typedef std::vector<DbAddDelColumnInfo> type_ColumnTypes;
   type_ColumnTypes m_ColumnTypes;
@@ -319,6 +326,8 @@ protected:
 
   bool m_columns_ready;
   bool m_allow_view;
+  bool m_allow_view_details;
+  Gtk::TreeViewColumn* m_treeviewcolumn_button;
 
   //signals:
   type_signal_user_added m_signal_user_added;
